@@ -16,6 +16,7 @@ from .const import (
     SystemAttribute,
     UserAttribute,
 )
+from .exceptions import VivintSkyApiError
 from .pubnub import PN_CHANNEL, PN_SUBSCRIBE_KEY, VivintPubNubSubscribeListener
 from .system import System
 from .utils import first_or_none
@@ -37,8 +38,8 @@ class Account:
         """Initialize an account."""
         self.__connected = False
         self.__load_devices = False
-        self.__pubnub: PubNubAsyncio = None
-        self.__pubnub_listener: VivintPubNubSubscribeListener = None
+        self.__pubnub: PubNubAsyncio | None = None
+        self.__pubnub_listener: VivintPubNubSubscribeListener | None = None
         self.vivintskyapi = VivintSkyApi(
             username=username,
             password=password,
@@ -48,14 +49,12 @@ class Account:
         self.systems: list[System] = []
 
     @property
-    def connected(self):
+    def connected(self) -> bool:
         """Return True if connected."""
         return self.__connected
 
     async def connect(
-        self,
-        load_devices: bool = False,
-        subscribe_for_realtime_updates: bool = False,
+        self, load_devices: bool = False, subscribe_for_realtime_updates: bool = False
     ) -> None:
         """Connect to the VivintSky API."""
         _LOGGER.debug("Connecting to VivintSky")
@@ -94,6 +93,7 @@ class Account:
         The pubnub code doesn't properly wait for the unsubscribe event to finish or to
         be canceled, so we have to manually do it by finding the coroutine in asyncio.
         """
+        assert self.__pubnub
         self.__pubnub.unsubscribe_all()
         tasks = [
             task
@@ -112,13 +112,13 @@ class Account:
             _LOGGER.debug("Loading devices")
             await self.refresh()
 
-    async def refresh(self, authuser_data: dict = None) -> None:
+    async def refresh(self, authuser_data: dict | None = None) -> None:
         """Refresh the account."""
         # make a call to vivint's authuser endpoint to get a list of all the system_accounts (locations) & panels if not supplied
         if not authuser_data:
             try:
                 authuser_data = await self.vivintskyapi.get_authuser_data()
-            except ClientConnectionError:
+            except (ClientConnectionError, VivintSkyApiError):
                 _LOGGER.error("Unable to refresh system(s)")
 
         if authuser_data:
@@ -129,7 +129,8 @@ class Account:
                 # is this an existing account_system?
                 system = first_or_none(
                     self.systems,
-                    lambda system: system.id == system_data[SystemAttribute.PANEL_ID],
+                    lambda system, system_data=system_data: system.id  # type: ignore
+                    == system_data[SystemAttribute.PANEL_ID],
                 )
                 if system:
                     await system.refresh()
@@ -150,14 +151,19 @@ class Account:
                 len(authuser_data[AuthUserAttribute.USERS][UserAttribute.SYSTEM]),
             )
 
-    async def subscribe_for_realtime_updates(self, authuser_data: dict = None) -> None:
+    async def subscribe_for_realtime_updates(
+        self, authuser_data: dict | None = None
+    ) -> None:
         """Subscribe to PubNub for realtime updates."""
         # make a call to vivint's authuser endpoint to get message broadcast channel if not supplied
         if not authuser_data:
             authuser_data = await self.vivintskyapi.get_authuser_data()
 
+        user_data = authuser_data[AuthUserAttribute.USERS]
+
         pnconfig = PNConfiguration()
         pnconfig.subscribe_key = PN_SUBSCRIBE_KEY
+        pnconfig.uuid = f"pn-{user_data[UserAttribute.ID].upper()}"
         pnconfig.ssl = True
         pnconfig.reconnect_policy = PNReconnectionPolicy.LINEAR
         pnconfig.heartbeat_notification_options = (
@@ -170,7 +176,9 @@ class Account:
         )
         self.__pubnub.add_listener(self.__pubnub_listener)
 
-        pn_channel = f"{PN_CHANNEL}#{authuser_data[AuthUserAttribute.USERS][UserAttribute.MESSAGE_BROADCAST_CHANNEL]}"
+        pn_channel = (
+            f"{PN_CHANNEL}#{user_data[UserAttribute.MESSAGE_BROADCAST_CHANNEL]}"
+        )
         self.__pubnub.subscribe().channels(pn_channel).with_presence().execute()
 
     def handle_pubnub_message(self, message: dict) -> None:
