@@ -17,7 +17,7 @@ DEVICE = "device"
 
 def get_device_class(device_type: str) -> Type[VivintDevice]:
     """Map a device_type string to the class that implements that device."""
-    from . import UnknownDevice
+    # pylint: disable=import-outside-toplevel
     from .camera import Camera
     from .door_lock import DoorLock
     from .garage_door import GarageDoor
@@ -30,9 +30,9 @@ def get_device_class(device_type: str) -> Type[VivintDevice]:
         DeviceType.CAMERA: Camera,
         DeviceType.DOOR_LOCK: DoorLock,
         DeviceType.GARAGE_DOOR: GarageDoor,
-        DeviceType.MULTILEVEL_SWITCH: MultilevelSwitch,
+        DeviceType.MULTI_LEVEL_SWITCH: MultilevelSwitch,
         DeviceType.THERMOSTAT: Thermostat,
-        DeviceType.TOUCH_PANEL: VivintDevice,
+        DeviceType.PANEL: VivintDevice,
         DeviceType.WIRELESS_SENSOR: WirelessSensor,
     }
 
@@ -42,21 +42,21 @@ def get_device_class(device_type: str) -> Type[VivintDevice]:
 class VivintDevice(Entity):
     """Class to implement a generic vivint device."""
 
-    def __init__(self, data: dict, alarm_panel: AlarmPanel = None) -> None:
+    def __init__(self, data: dict, alarm_panel: AlarmPanel | None = None) -> None:
         """Initialize a device."""
         super().__init__(data)
         self.alarm_panel = alarm_panel
-        self._manufacturer = None
-        self._model = None
+        self._manufacturer: str | None = None
+        self._model: str | None = None
         self._capabilities = (
             {
                 CapabilityCategoryType(capability_category.get(Attribute.TYPE)): [
                     CapabilityType(capability)
                     for capability in capability_category.get(Attribute.CAPABILITY)
                 ]
-                for capability_category in data.get(Attribute.CAPABILITY_CATEGORY)
+                for capability_category in caca
             }
-            if data.get(Attribute.CAPABILITY_CATEGORY)
+            if (caca := data.get(Attribute.CAPABILITY_CATEGORY)) is not None
             else None
         )
         self._parent: VivintDevice | None = None
@@ -66,9 +66,9 @@ class VivintDevice(Entity):
         return f"<{self.__class__.__name__} {self.id}, {self.name}>"
 
     @property
-    def id(self) -> int:
+    def id(self) -> int:  # pylint: disable=invalid-name
         """Device's id."""
-        return self.data[Attribute.ID]
+        return int(self.data[Attribute.ID])
 
     @property
     def is_valid(self) -> bool:
@@ -80,6 +80,15 @@ class VivintDevice(Entity):
         """Device's name."""
         return self.data.get(Attribute.NAME)
 
+    @property
+    def battery_level(self) -> int | None:
+        """Return the device's battery level."""
+        if not self.has_battery:
+            return None
+        if (battery_level := self.data.get(Attribute.BATTERY_LEVEL)) not in (None, ""):
+            return battery_level
+        return 0 if self.low_battery else 100
+
     @property
     def capabilities(
         self,
@@ -90,13 +99,26 @@ class VivintDevice(Entity):
     @property
     def device_type(self) -> DeviceType:
         """Return the device type."""
-        return DeviceType(self.data[Attribute.TYPE])
+        return DeviceType(self.data.get(Attribute.TYPE))
+
+    @property
+    def has_battery(self) -> bool:
+        """Return `True` if the device has battery details."""
+        return (
+            self.data.get(Attribute.BATTERY_LEVEL) is not None
+            or self.data.get(Attribute.LOW_BATTERY) is not None
+        )
 
     @property
     def is_subdevice(self) -> bool:
         """Return if this device is a subdevice."""
         return self._parent is not None
 
+    @property
+    def low_battery(self) -> bool | None:
+        """Return `True` if the device's battery level is low."""
+        return self.data.get(Attribute.LOW_BATTERY, False) if self.has_battery else None
+
     @property
     def manufacturer(self) -> str | None:
         """Return the manufacturer for this device."""
@@ -114,7 +136,7 @@ class VivintDevice(Entity):
     @property
     def panel_id(self) -> int:
         """Return the id of the panel this device is associated to."""
-        return self.data.get(Attribute.PANEL_ID)
+        return int(self.data[Attribute.PANEL_ID])
 
     @property
     def parent(self) -> VivintDevice | None:
@@ -130,22 +152,17 @@ class VivintDevice(Entity):
         return serial_number
 
     @property
-    def software_version(self) -> str:
+    def software_version(self) -> str | None:
         """Return the software version of this device, if any."""
-        # panels
-        current_software_version = self.data.get(Attribute.CURRENT_SOFTWARE_VERSION)
-        # z-wave devices (some)
-        firmware_version = (
-            ".".join(
-                [
-                    str(i)
-                    for s in self.data.get(Attribute.FIRMWARE_VERSION) or []
-                    for i in s
-                ]
-            )
-            or None
+        # current software version
+        if (csv := self.data.get(Attribute.CURRENT_SOFTWARE_VERSION)) is not None:
+            return str(csv)
+        # firmware version
+        return (
+            ".".join([str(i) for s in fwv for i in s])
+            if (fwv := self.data.get(Attribute.FIRMWARE_VERSION)) is not None
+            else None
         )
-        return current_software_version or firmware_version
 
     @property
     def vivintskyapi(self) -> VivintSkyApi:
@@ -153,10 +170,10 @@ class VivintDevice(Entity):
         assert self.alarm_panel, """no alarm panel set for this device"""
         return self.alarm_panel.system.vivintskyapi
 
-    def get_zwave_details(self):
+    def get_zwave_details(self) -> None:
         """Get Z-Wave details."""
         if self.data.get("zpd") is None:
-            return None
+            return
 
         result = get_zwave_device_info(
             self.data.get("manid"),
@@ -178,8 +195,6 @@ class VivintDevice(Entity):
         else:
             self._model = "Unknown"
 
-        return [self._manufacturer, self._model]
-
     def emit(self, event_name: str, data: dict) -> None:
         """Add device data and then send to parent."""
         if data.get(DEVICE) is None:
@@ -195,7 +210,7 @@ class BypassTamperDevice(VivintDevice):
     def is_bypassed(self) -> bool:
         """Return True if the device is bypassed."""
         return (
-            self.data.get(Attribute.BYPASSED, ZoneBypass.UNBYPASSED)
+            int(self.data.get(Attribute.BYPASSED, ZoneBypass.UNBYPASSED))
             != ZoneBypass.UNBYPASSED
         )
 
